@@ -72,6 +72,10 @@ SosExampleServices <- function() {
 		parseElementType,
 		parseEncoding,
 		parseValues,
+		parseSwePosition,
+		parseLocation,
+		parseVector,
+		parseCoordinate,
 		#
 		parseGeometryObservation,
 		parseCategoryObservation,
@@ -98,6 +102,10 @@ names(.sosDefaultParsers) <- list(
 		sweElementTypeName,
 		sweEncodingName,
 		sweValuesName,
+		swePositionName,
+		sweLocationName,
+		sweVectorName,
+		sweCoordinateName,
 		#
 		omGeometryObservationName,
 		omCategoryObservationName,
@@ -354,6 +362,10 @@ sosDefaultColumnNameLat <- "lat"
 sosDefaultColumnNameLon <- "lon"
 sosDefaultColumnNameSRS <- "SRS"
 
+# Created by library(RColorBrewer); brewer.pal(12, "Paired")
+sosDefaultColorPalette <- c("#A6CEE3", "#1F78B4", "#B2DF8A", "#33A02C",
+		"#FB9A99", "#E31A1C", "#FDBF6F", "#FF7F00", "#CAB2D6", "#6A3D9A",
+		"#FFFF99", "#B15928")
 
 SosDefaults <- function() {
 	.defaults <- list(sosDefaultCharacterEncoding,
