@@ -1,6 +1,7 @@
 # Copyright (C) 2010 by 52 North Initiative for Geospatial Open Source Software GmbH, Contact: info@52north.org
 # This program is free software; you can redistribute and/or modify it under the terms of the GNU General Public License version 2 as published by the Free Software Foundation. This program is distributed WITHOUT ANY WARRANTY; even without the implied WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with this program (see gpl-2.0.txt). If not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or visit the Free Software Foundation web page, http://www.fsf.org.
-# Author: Daniel Nuest (daniel.nuest@uni-muenster.de)
+# Author: 	Daniel Nuest (daniel.nuest@uni-muenster.de)
+#			Edzer Pebesma (edzer.pebesma@uni-muenster.de)
 # Project: sos4R - visit the project web page, http://www.nordholmen.net/sos4r
 library("sos4R")
 
@@ -12,7 +13,9 @@ library("sos4R")
 aqe.converters <- SosDataFieldConvertingFunctions(
 		"http://giv-genesis.uni-muenster.de:8080/SOR/REST/phenomenon/OGC/Concentration[PM10]" = sosConvertDouble,
 		"http://giv-genesis.uni-muenster.de:8080/SOR/REST/phenomenon/OGC/Concentration[NO2]" = sosConvertDouble,
-		"http://giv-genesis.uni-muenster.de:8080/SOR/REST/phenomenon/OGC/Concentration[O3]" = sosConvertDouble)
+		"http://giv-genesis.uni-muenster.de:8080/SOR/REST/phenomenon/OGC/Concentration[O3]" = sosConvertDouble,
+		"http://www.opengis.net/def/property/OGC/0/SamplingTime" = sosConvertTime,
+		"http://www.opengis.net/def/property/OGC/0/FeatureOfInterest" = sosConvertString)
 
 # Create the SOS connection:
 aqe <- SOS(url = "http://giv-uw.uni-muenster.de:8080/AQE/sos",
@@ -26,6 +29,8 @@ names(aqe.offerings)
 ###########
 # Plot SOS:
 library(maps); library(mapdata); library(maptools)
+if(!require(rgdal, quietly = TRUE))
+	print("rgdal not present: CRS values will not be converted correctly")
 data(worldHiresMapEnv)
 crs <- sosGetCRS(aqe)[[1]]
 region <- map.where(database = "worldHires",
@@ -62,16 +67,26 @@ dec2003 = sosCreateEventTimeList(sosCreateTimePeriod(sos = aqe,
 obs.no2.12Hrs <- getObservation(sos = aqe, # inspect = TRUE,
 		offering = aqe.off.no2,
 		#procedure = sosProcedures(aqe.off.no2)[1:20],
-		saveOriginal = TRUE,# saves file in getwd()
+		saveOriginal = TRUE, # saves file in getwd()
 		eventTime = dec2003.12Hrs)
 # 38 secs
 
+################################################
+# Reloading the file later for further analysis:
+# Use the file name printed out by the getObservation(...) call or check your
+# working directory:
+list.files(path = getwd(), pattern = sosName(aqe.off.no2))
+#parseFile("NO2_2011-03-03_11:31:23.xml")
+
+##############################################
 # Explore the returned observation collection:
 obs.no2.12Hrs
 # There is one observatio for every FOI / procedure combination :
 names(obs.no2.12Hrs)[1:3]
 
-# Subset the collection (features, observed properties and procedures):
+########################
+# Subset the collection:
+# (features, observed properties and procedures):
 # sosFeatureIds(obs.no2.12Hrs)[c(1,100)]
 obs.no2.12Hrs[sosFeatureIds(obs.no2.12Hrs)[c(1,100)]]
 # sosObservedProperties(obs.no2.12Hrs)[2]
@@ -103,16 +118,18 @@ result.no2.12Hrs <- sosResult(obs.no2.12Hrs, coordinates = TRUE)
 summary(result.no2.12Hrs)
 NO2 <- colnames(result.no2.12Hrs)[[3]]
 
+#################################################
 # Subset and sort the data with subset or sort_df
 subset(result.no2.12Hrs, feature=="foi_DEBY109")
-require("reshape")
+library("reshape")
 # The ten highest values:
 tail(sort_df(result.no2.12Hrs, NO2), 10)
 
+########################
 # Histogram of NO2 data:
 hist(result.no2.12Hrs[,3], main = "NO2")
 # Test plot:
-plot(result.no2.12Hrs[["Time"]], result.no2.12Hrs[[NO2]])
+plot(result.no2.12Hrs[["SamplingTime"]], result.no2.12Hrs[[NO2]])
 
 
 ################################################################################
@@ -120,7 +137,7 @@ plot(result.no2.12Hrs[["Time"]], result.no2.12Hrs[[NO2]])
 obs.no2.crs <- sosGetCRS(obs.no2.12Hrs)
 no2.spdf <- SpatialPointsDataFrame(
 		coords = result.no2.12Hrs[,c("lon", "lat")],
-		data = result.no2.12Hrs[,c("Time", "feature", NO2)],
+		data = result.no2.12Hrs[,c("SamplingTime", "feature", NO2)],
 		proj4string = obs.no2.crs)
 bbox(no2.spdf)
 #obs.no2.bbox <- sosBoundedBy(obs.no2.12Hrs, bbox = TRUE) # equal
@@ -134,7 +151,7 @@ summary(no2.spdf.shortcut)
 
 ####################################
 # Plot stations with background map:
-require("mapdata")
+library("mapdata")
 germany.p <- pruneMap(map(database = "worldHires", region = "Germany",
 				plot = FALSE))
 germany.sp <- map2SpatialLines(germany.p, proj4string = obs.no2.crs)
@@ -150,17 +167,45 @@ bubble(no2.spdf, zcol = 3, maxsize = 2, col = c("#1155ff"),
 
 ################################################################################
 # Transform to UTM for kriging and background map:
-require("rgdal")
 utm32 = CRS("+proj=utm +zone=32 +datum=WGS84")
 germany.utm <- spTransform(germany.sp, utm32)
 no2.spdf.utm = spTransform(no2.spdf, utm32)
 plot(germany.utm, col = "grey")
-plot(no2.spdf.utm, add = TRUE)
-title(main = "NO2 Germany", sub = "UTM projection")
-
+points(no2.spdf.utm, cex=.5, pch=3)
+title(main = "NO2 Sensor Stations, Germany", sub = "UTM projection")
  
 ################################################################################
-# TODO Kriging with automap?
+# Spatial interpolation, averaging over (essentially ignoring) time:
+library(cshapes) # get a polygon of Germany, rather than a set of lines:
+cs = cshp()
+g = spTransform(cs[cs$CNTRY_NAME=="Germany",], utm32)
+# create a grid of points within Germany:
+grdpoints = SpatialPoints(makegrid(germany.utm),utm32)
+grd = SpatialPixels(grdpoints)[g]
+names(no2.spdf.utm)[3] = "NO2"
+library(gstat)
+no2.id = idw(NO2~1, no2.spdf.utm, grd)
+lt=list(list("sp.polygons", g),
+	list("sp.points", no2.spdf.utm, col=grey(.7), cex=.5))
+spplot(no2.id[1], sp.layout = lt, col.regions = bpy.colors(),
+		main = paste("IDW Interpolation of NO2,",
+				min(no2.spdf.utm$SamplingTime), "to",
+				max(no2.spdf.utm$SamplingTime)))
+
+## now get the values of 2003-12-01 12:00:00 CET, or the third time stamp
+# by creating a spatio-temporal structure, and indexing the time axis:
+t12h = unique(no2.spdf.utm$SamplingTime)[3]
+library(spacetime)
+no2.stidf = STIDF(as(no2.spdf.utm, "SpatialPoints"), 
+	no2.spdf.utm$SamplingTime, data.frame(NO2 = no2.spdf.utm$NO2))
+no2.stfdf = as(no2.stidf, "STFDF")
+no2.12h = no2.stfdf[,3,"NO2"]
+no2.12h2 = no2.stfdf[,t12h,"NO2"]
+all.equal(no2.12h, no2.12h2)
+# inverse distance interpolation of the 12:00h NO2 values:
+no2.12h.id = idw(NO2~1, no2.12h[!is.na(no2.12h$NO2),], grd)
+spplot(no2.12h.id[1], sp.layout = lt, col.regions = bpy.colors(),
+		main = paste("IDW Interpolation of NO2,", t12h))
 
 ################################################################################
 # Plot with whole year 2004 for one station:
@@ -168,8 +213,14 @@ title(main = "NO2 Germany", sub = "UTM projection")
 denw095 <- "urn:ogc:object:feature:Sensor:EEA:airbase:4.0:DENW095"
 denw095.descr <- describeSensor(aqe, denw095)
 denw095.descr
-#procedure1.descr@xml
+#denw095.descr@xml
 
+# Get the identifier of the station:
+denw095.id <- xmlValue(getNodeSet(doc = denw095.descr@xml,
+		path = "//sml:Term[@definition='urn:ogc:def:identifier:OGC:1.0:longName']/sml:value/text()",
+		namespaces = sos4R:::.sosNamespaceDefinitionsSML)[[1]])
+
+# Request observations:
 obs.denw095.2004 <- getObservation(sos = aqe, # inspect = TRUE,
 		offering = aqe.off.no2,
 		procedure = denw095,
@@ -177,21 +228,20 @@ obs.denw095.2004 <- getObservation(sos = aqe, # inspect = TRUE,
 						begin = as.POSIXct("2004/01/01"),
 						end = as.POSIXct("2004/12/31")))
 )
-# second(s)
 
-# Plot it:
+# Print statistical information and plot time series:
 data.denw095.2004 <- sosResult(obs.denw095.2004)
 summary(data.denw095.2004)
 
 denw095.NO2.attributes <- attributes(data.denw095.2004[[NO2]])
-#data.denw095.2004.locRegr = loess(
-#		formula = data.denw095.2004[[NO2]]~data.denw095.2004[["Time"]],
-#		data = data.denw095.2004[[NO2]])
-plot(data.denw095.2004[["Time"]], data.denw095.2004[[NO2]], type = "l",
-		main = "NO2 in Muenster", sub = denw095,
+plot(data.denw095.2004[["SamplingTime"]], data.denw095.2004[[NO2]], type = "l",
+		main = paste("NO2 in", denw095.id, "2004"), sub = denw095,
 		xlab = "Time",
-		ylab = paste("NO2 in ",
+		ylab = paste("NO2 (",
 				denw095.NO2.attributes[["unit of measurement"]],
-						sep = ""))
-#lines(data.denw095.2004$Time, data.denw095.2004.locRegr$fitted, col = 'red', lwd=3)
+				")", sep = ""))
+data.denw095.2004.locRegr = loess(data.denw095.2004[[NO2]]~as.numeric(data.denw095.2004[["SamplingTime"]]),
+		data.denw095.2004, enp.target = 30)
+p = predict(data.denw095.2004.locRegr)
+lines(p ~ data.denw095.2004[["SamplingTime"]], col = 'blue',lwd = 4)
 
